StackTrace

Struct StackTrace 

pub struct StackTrace {
    pub thread_koid: Option<u64>,
    pub frames: Option<Vec<CallFrame>>,
    /* private fields */
}
A stack trace and the identifier of the thread it belongs to.

Fields

thread_koid: Option<u64>

The koid of the thread.

frames: Option<Vec<CallFrame>>

The stack frames, listed bottom-to-top.

The first frame has the lowest frame pointer (FP) value, and subsequent frames have increasing FPs. The difference between the FP of the last frame and the FP of the first frame represents the (approximate) overall stack size consumed by this trace.